"""
TOON (Token-Oriented Object Notation) Python API

A Python library for encoding and decoding TOON format,
a compact data format optimized for LLM token usage.
"""

from tost.tost import encode, decode

__all__ = ["encode", "decode"]
__version__ = "0.1.0"

